@@ -122,7 +122,7 @@ else:
     config.set('user', 'duration',  '7.5')
     config.set('user', 'used_durations',  '7.5 7.0')
     config.set('user', 'duration_or_alarm', 'duration')
-    config.set('user', 'language', 'eng')
+    config.set('user', 'language', 'rus')
     config.set('user', 'alarm_threshold', '100')
     config.set('user', 'alarm_play_time_sec', '60')
     #config.set('user', 'snooze_time_min', '10')
